@@ -41,10 +41,4 @@ class UpdateDt:
 @dataclass
 class BotCommandDt:
     command: str
-    description: str
-
-
-@dataclass
-class CatchMultipleMessageDt:
-    user_id: str
-    messages = []
+    description: str
\ No newline at end of file
